use "estimation data for IO", clear

*cd c:\ado\
*capture mkdir plus
*cd plus
*capture mkdir x
*cd x
capture copy http://www.polsci.org/pluemper/xtfevd.ado xtfevd.ado
capture copy http://www.polsci.org/pluemper/xtfevd.hlp xtfevd.hlp

* Executive Constraint >=7 (use Cox to justify this)
capture drop comp
gen comp = 0 
replace comp=1 if xconst>=7
replace comp=. if xconst==.

capture drop L_spread
tsset ccode year
*gen L_spread = L.spread
gen L_spread = L1.avg_spread

capture drop cb_war
gen cb_war = cb*war

*log using "C:\Users\Owner\Dropbox\Central Banks and War\IO R&R Results.log", replace

*TEST: Test for serial correlation
tsset ccode year
xtserial avg_spread 
xtserial avg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar

*TEST: Arellano and Bond Test (test to determine if the use of a lagged dependent variable is more appropriate than assuming the time dependence in average spread is due to serial correlation in the error term)
* Procedure: determine if assumptions of the Arrellano and Bond procedure don't hold (Bowblis 2010:226).  Specifically, the Arellano and Bond procedure assumes serially uncorrelated errors (Arellan and Bond 1991: 291). 
* The Arellano and Bond test reveals that the null hypothesis of no serial correlation is rejected with a p-value of 0.01. 
xtabond  avg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar,  lags(1) maxldep(3) robust

*TEST: Check for Non-stationarity
tempfile station
save `station', replace
tsreport, report0 panel list
drop if ccode==70 & year<1824
drop if ccode==100 & year<1884
drop if ccode==140 & year<1826
drop if ccode==155 & year<1822
drop if ccode==390 & year<1864
tsreport, report0 panel list
tsset ccode year
* Perform the Maddala and Wu (1999) test (shows no unit root, so no need to first difference the data)
xtfisher avg_spread if ccode<1000, lag(2)

use `station', clear

** Results with Lagged DV
capture drop Lavg_spread
gen Lavg_spread = L.avg_spread

* F-test
xi: reg avg_spread Lavg_spread cb war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar i.ccode
estimates store m1

xi: reg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar i.ccode
estimates store m2

ftest m1 m2

** 4th degree time polynomial
capture drop year2 year3 year4
gen year2 = year*year
gen year3 = year*year*year
gen year4 = year*year*year*year

** THE KEY MODELS
label variable cb "Central Bank"
label variable comp "Representative Institutions"
label variable cent "Centralization"
label variable L_spread "Lag of Average Spread"
label variable topitaxrate2 "Top Tax Rate"
label variable trade "Trade Agreement"
label variable gdp "Iron and Steel Production/Capita"
label variable lnpop "Total Population"
label variable growth "Growth in Iron and Steel Production"
label variable urban "Urbanization Rate"
label variable internal_disruption "Internal Political Crisis"
label variable GS "Gold Standard"
label variable Default "Default"
label variable war "War Period"
label variable year "Year"
label variable cw "Civil War"

reg avg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar
lincom cb + cb_war
estimates store ols

xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4, fe
estimates store fixed
lincom cb + cb_war
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4, re
estimates store random
lincom cb + cb_war


** Country Removal (FE v RE)

* Remove UK
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if ccode~=200, fe
lincom cb + cb_war
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if ccode~=200, re
lincom cb + cb_war

* Remove France
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if ccode~=220, fe
lincom cb + cb_war
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if ccode~=220, re
lincom cb + cb_war

* Remove Prussia/Germany
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if ccode~=255, fe
lincom cb + cb_war
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if ccode~=255, re
lincom cb + cb_war

* Remove Russia
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if ccode~=365, fe
lincom cb + cb_war
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if ccode~=365, re
lincom cb + cb_war

* Remove USA
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if ccode~=2, fe
lincom cb + cb_war
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if ccode~=2, re
lincom cb + cb_war

* Remove Italy
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if ccode~=325, fe
lincom cb + cb_war
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if ccode~=325, re
lincom cb + cb_war

* Remove Austria
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if ccode~=300, fe
lincom cb + cb_war
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar  year year2 year3 year4 if ccode~=300, re
lincom cb + cb_war




** Country Removal (xtregar)

* Remove UK
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar if ccode~=200, fe
lincom cb + cb_war
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar if ccode~=200, re
lincom cb + cb_war

* Remove France
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar if ccode~=220, fe
lincom cb + cb_war
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar if ccode~=220, re
lincom cb + cb_war

* Remove Prussia/Germany
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar if ccode~=255, fe
lincom cb + cb_war
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar if ccode~=255, re
lincom cb + cb_war

* Remove Russia
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar if ccode~=365, fe
lincom cb + cb_war
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar if ccode~=365, re
lincom cb + cb_war

* Remove USA
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar if ccode~=2, fe
lincom cb + cb_war
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar if ccode~=2, re
lincom cb + cb_war

* Remove Italy
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar if ccode~=325, fe
lincom cb + cb_war
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar if ccode~=325, re
lincom cb + cb_war

* Remove Austria
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar if ccode~=300, fe
lincom cb + cb_war
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar if ccode~=300, re
lincom cb + cb_war


* Hausman test: Test for fixed or random effects (shows no systematic difference in estimates)
hausman fixed random

**XTREGAR Models
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar, fe
estimates store xtregarfe
lincom cb + cb_war
xtregar avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar, re
estimates store xtregarre
lincom cb + cb_war

** FEVD Models
xtfevd avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar, invariant(cb)
estimates store xtfevd
lincom cb + cb_war

xtfevd avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar, invariant(cb) ar1
estimates store xtfevdar1
lincom cb + cb_war

** Driscoll and Kraay Models 
xtscc avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar, lag(1)
estimates store xtscc1
lincom cb + cb_war

xtscc avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar, fe lag(1)
estimates store xtscc2
lincom cb + cb_war


****** Supplemental Analysis
****************************

** Moving Average
gen Move5_spread = (avg_spread + L.avg_spread + L2.avg_spread + L3.avg_spread + L4.avg_spread + L5.avg_spread)/5
gen Move5_cb = (cb + L.cb + L2.cb + L3.cb + L4.cb + L5.cb)/5
gen Move5_war = (war + L.war + L2.war + L3.war + L4.war + L5.war)/5
gen Move5_comp = (comp + L.comp + L2.comp + L3.comp + L4.comp + L5.comp)/5
gen Move5_topitaxrate2 = (topitaxrate2 + L.topitaxrate2 + L2.topitaxrate2 + L3.topitaxrate2 + L4.topitaxrate2 + L5.topitaxrate2)/5
gen Move5_trade = (trade + L.trade + L2.trade + L3.trade + L4.trade + L5.trade)/5
gen Move5_gdp = (gdp + L.gdp + L2.gdp + L3.gdp + L4.gdp + L5.gdp)/5
gen Move5_lnpop = (lnpop + L.lnpop + L2.lnpop + L3.lnpop + L4.lnpop + L5.lnpop)/5
gen Move5_growth = (growth + L.growth + L2.growth + L3.growth + L4.growth + L5.growth)/5
gen Move5_urban = (urban + L.urban + L2.urban + L3.urban + L4.urban + L5.urban)/5
gen Move5_internal_disruption = (internal_disruption + L.internal_disruption + L2.internal_disruption + L3.internal_disruption + L4.internal_disruption + L5.internal_disruption)/5
gen Move5_GS = (lnpop + L.lnpop + L2.lnpop + L3.lnpop + L4.lnpop + L5.lnpop)/5
gen Move5_Default = (Default + L.Default + L2.Default + L3.Default + L4.Default + L5.Default)/5
gen Move5_cw = (cw + L.cw + L2.cw + L3.cw + L4.cw + L5.cw)/5
gen Move5_colwar = (colwar + L.colwar + L2.colwar + L3.colwar + L4.colwar + L5.colwar)/5
gen Move5_cb_war = Move5_war*Move5_cb

sum Move5_war 
hist Move5_war
reg Move5_spread Move5_cb Move5_war Move5_cb_war Move5_comp /*cent*/ Move5_topitaxrate2 Move5_trade Move5_gdp Move5_lnpop Move5_growth Move5_urban Move5_internal_disruption Move5_GS Move5_Default Move5_cw Move5_colwar
lincom Move5_cb + Move5_cb_war*0.0
lincom Move5_cb + Move5_cb_war*0.5
lincom Move5_cb + Move5_cb_war*0.75
lincom Move5_cb + Move5_cb_war*1
lincom Move5_cb + Move5_cb_war*1.2

** With year fixed effects
xi: reg avg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar i.year

** Conditioned on Regime Type
xtreg avg_spread Lavg_spread cb war cb_war topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if comp==0, re
lincom cb + cb_war
xtreg avg_spread Lavg_spread cb war cb_war topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if comp==1, re
lincom cb + cb_war

** With the centralization variable
xtreg avg_spread Lavg_spread cb war cb_war comp cent topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4, re
lincom cb + cb_war

**Remove the UK
xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if ccode~=200, re
lincom cb + cb_war

**Yield
gen Lyield = L.master_yield 
xtreg master_yield Lyield cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4, re
lincom cb + cb_war

** Split between "developed" and "developing" world:
sum gdp, detail
local median = r(p50)
capture drop rich
capture drop cb_rich
capture drop comp_rich
capture drop comp_rich_cb
capture drop cb_comp
gen rich = 0
replace rich = 1 if gdp>`median'

xtreg avg_spread Lavg_spread cb war cb_war comp topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if rich==0, re
lincom cb + cb_war
xtreg avg_spread Lavg_spread cb war cb_war com topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4 if rich==1, re
lincom cb + cb_war


** Alternative GS measure
capture drop GS
gen GS = 0
** Flandreau and Zumer coding
replace GS=1 if year>=1883 & year<=1884 & ccode==160
replace GS=1 if year>=1899 & ccode==160
replace GS=1 if year>=1896 & ccode==300
replace GS=1 if year>=1880 & ccode==211
replace GS=1 if year==1889 & ccode==140
replace GS=1 if year>=1906 & ccode==140
replace GS=1 if year>=1880 & ccode==390
replace GS=1 if year>=1880 & ccode==220
replace GS=1 if year>=1880 & ccode==255
replace GS=1 if year>=1910 & ccode==350
replace GS=1 if year>=1884 & year<=1891 & ccode==325
replace GS=1 if year>=1902 & ccode==325
replace GS=1 if year>=1880 & ccode==210
replace GS=1 if year>=1880 & ccode==385
replace GS=1 if year>=1880 & year<=1890 & ccode==235
replace GS=1 if year>=1897 & ccode==365
replace GS=1 if year>=1880 & ccode==200
replace GS=1 if year>=1880 & ccode==225
replace GS=1 if year>=1880 & ccode==380

xtreg avg_spread Lavg_spread cb war cb_war comp /*cent*/ topitaxrate2 trade gdp lnpop growth urban internal_disruption GS Default cw colwar year year2 year3 year4, fe
lincom cb + cb_war


